<?php
/**
 * ia language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesIa.php?view=co
 * @author robocap <robocap1@gmail.com>
 * @author Martijn Dekker <martijn@inlv.org>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Modificar iste pagina';
$lang['btn_source']            = 'Monstrar codice-fonte';
$lang['btn_show']              = 'Monstrar pagina';
$lang['btn_create']            = 'Crear iste pagina';
$lang['btn_search']            = 'Cercar';
$lang['btn_save']              = 'Salveguardar';
$lang['btn_preview']           = 'Previsualisar';
$lang['btn_top']               = 'Retornar al initio';
$lang['btn_newer']             = '<< plus recente';
$lang['btn_older']             = 'minus recente >>';
$lang['btn_revs']              = 'Versiones ancian';
$lang['btn_recent']            = 'Modificationes recente';
$lang['btn_upload']            = 'Incargar';
$lang['btn_cancel']            = 'Cancellar';
$lang['btn_index']             = 'Indice';
$lang['btn_secedit']           = 'Modificar';
$lang['btn_login']             = 'Aperir session';
$lang['btn_logout']            = 'Clauder session';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Actualisar';
$lang['btn_delete']            = 'Deler';
$lang['btn_back']              = 'Retornar';
$lang['btn_backlink']          = 'Retroligamines';
$lang['btn_backtomedia']       = 'Retornar al selection de files multimedia';
$lang['btn_subscribe']         = 'Gerer subscriptiones';
$lang['btn_profile']           = 'Actualisar profilo';
$lang['btn_reset']             = 'Reinitialisar';
$lang['btn_draft']             = 'Modificar version provisori';
$lang['btn_recover']           = 'Recuperar version provisori';
$lang['btn_draftdel']          = 'Deler version provisori';
$lang['btn_revert']            = 'Restaurar';
$lang['btn_register']          = 'Crear conto';
$lang['loggedinas']            = 'Session aperite como';
$lang['user']                  = 'Nomine de usator';
$lang['pass']                  = 'Contrasigno';
$lang['newpass']               = 'Nove contrasigno';
$lang['oldpass']               = 'Confirmar contrasigno actual';
$lang['passchk']               = 'un altere vice';
$lang['remember']              = 'Memorar me';
$lang['fullname']              = 'Nomine real';
$lang['email']                 = 'E-mail';
$lang['profile']               = 'Profilo de usator';
$lang['badlogin']              = 'Le nomine de usator o le contrasigno es incorrecte.';
$lang['minoredit']             = 'Modificationes minor';
$lang['draftdate']             = 'Version provisori automaticamente salveguardate le';
$lang['nosecedit']             = 'Le pagina ha essite modificate intertanto. Le informationes del section es ora obsolete, dunque le pagina complete ha essite cargate in su loco.';
$lang['regmissing']            = 'Es necessari completar tote le campos.';
$lang['reguexists']            = 'Regrettabilemente, un usator con iste nomine ja existe.';
$lang['regsuccess']            = 'Le conto ha essite create e le contrasigno ha essite inviate per e-mail.';
$lang['regsuccess2']           = 'Le conto ha essite create.';
$lang['regmailfail']           = 'Il pare que un error occurreva durante le invio del message con le contrasigno. Per favor contacta le administrator!';
$lang['regbadmail']            = 'Le adresse de e-mail date pare esser invalide. Si tu pensa que isto es un error, contacta le administrator.';
$lang['regbadpass']            = 'Le duo contrasignos date non es identic. Per favor reproba.';
$lang['regpwmail']             = 'Tu contrasigno de DokuWiki';
$lang['reghere']               = 'Tu non ha ancora un conto? Crea un, simplemente.';
$lang['profna']                = 'Iste wiki non supporta le modification de profilos.';
$lang['profnochange']          = 'Nulle modification, nihil a facer.';
$lang['profnoempty']           = 'Un nomine o adresse de e-mail vacue non es permittite.';
$lang['profchanged']           = 'Actualisation del profilo de usator succedite.';
$lang['pwdforget']             = 'Contrasigno oblidate? Obtene un altere';
$lang['resendna']              = 'Iste wiki non supporta le invio de un nove contrasigno.';
$lang['resendpwdmissing']      = 'Es necessari completar tote le campos.';
$lang['resendpwdnouser']       = 'Iste usator non ha essite trovate in le base de datos.';
$lang['resendpwdbadauth']      = 'Iste codice de authentication non es valide. Assecura te que tu ha usate le ligamine de confirmation complete.';
$lang['resendpwdconfirm']      = 'Un ligamine de confirmation ha essite inviate per e-mail.';
$lang['resendpwdsuccess']      = 'Tu nove contrasigno ha essite inviate per e-mail.';
$lang['license']               = 'Excepte ubi indicate alteremente, le contento in iste wiki es disponibile sub le licentia sequente:';
$lang['licenseok']             = 'Nota ben! Per modificar iste pagina tu accepta que tu contento essera publicate sub le conditiones del licentia sequente:';
$lang['searchmedia']           = 'Cercar file con nomine:';
$lang['searchmedia_in']        = 'Cercar in %s';
$lang['txt_upload']            = 'Selige le file a incargar';
$lang['txt_filename']          = 'Incargar como (optional)';
$lang['txt_overwrt']           = 'Reimplaciar le file existente';
$lang['lockedby']              = 'Actualmente serrate per';
$lang['lockexpire']            = 'Serratura expira le';
$lang['js']['willexpire']            = 'Tu serratura super le modification de iste pagina expirara post un minuta.\nPro evitar conflictos, usa le button Previsualisar pro reinitialisar le timer del serratura.';
$lang['js']['notsavedyet']     = 'Le modificationes non salveguardate essera perdite.\nRealmente continuar?';
$lang['rssfailed']             = 'Un error occurreva durante le obtention de iste syndication:';
$lang['nothingfound']          = 'Nihil ha essite trovate.';
$lang['mediaselect']           = 'Files multimedia';
$lang['fileupload']            = 'Incargar file multimedia';
$lang['uploadsucc']            = 'Incargamento succedite';
$lang['uploadfail']            = 'Incargamento fallite. Pote esser que le permissiones es incorrecte.';
$lang['uploadwrong']           = 'Incargamento refusate. Iste typo de file es prohibite!';
$lang['uploadexist']           = 'File ja existe. Nihil facite.';
$lang['uploadbadcontent']      = 'Le typo del contento incargate non corresponde al extension del nomine de file "%s".';
$lang['uploadspam']            = 'Le incargamento ha essite blocate per le lista nigre anti-spam.';
$lang['uploadxss']             = 'Le incargamento ha essite blocate a causa de contento possibilemente malitiose.';
$lang['uploadsize']            = 'Le file incargate es troppo grande. (Max. %s)';
$lang['deletesucc']            = 'Le file "%s" ha essite delite.';
$lang['deletefail']            = '"%s" non poteva esser delite. Verifica le permissiones.';
$lang['mediainuse']            = 'Le file "%s" non ha essite delite proque illo es ancora in uso.';
$lang['namespaces']            = 'Spatios de nomines';
$lang['mediafiles']            = 'Files disponibile in';
$lang['js']['searchmedia']     = 'Cercar files';
$lang['js']['keepopen']        = 'Mantener fenestra aperte post selection';
$lang['js']['hidedetails']     = 'Celar detalios';
$lang['js']['mediatitle']      = 'Configuration del ligamine';
$lang['js']['mediadisplay']    = 'Typo de ligamine';
$lang['js']['mediaalign']      = 'Alineamento';
$lang['js']['mediasize']       = 'Dimension del imagine';
$lang['js']['mediatarget']     = 'Destination del ligamine';
$lang['js']['mediaclose']      = 'Clauder';
$lang['js']['mediainsert']     = 'Inserer';
$lang['js']['mediadisplayimg'] = 'Monstrar le imagine.';
$lang['js']['mediadisplaylnk'] = 'Monstrar solmente le imagine.';
$lang['js']['mediasmall']      = 'Version parve';
$lang['js']['mediamedium']     = 'Version medie';
$lang['js']['medialarge']      = 'Version grande';
$lang['js']['mediaoriginal']   = 'Version original';
$lang['js']['medialnk']        = 'Ligamine al pagina de detalios';
$lang['js']['mediadirect']     = 'Ligamine directe verso le original';
$lang['js']['medianolnk']      = 'Nulle ligamine';
$lang['js']['medianolink']     = 'Non ligar verso le imagine';
$lang['js']['medialeft']       = 'Alinear le imagine verso le sinistra.';
$lang['js']['mediaright']      = 'Alinear le imagine verso le dextra.';
$lang['js']['mediacenter']     = 'Alinear le imagine in le medio.';
$lang['js']['medianoalign']    = 'Non alinear.';
$lang['js']['nosmblinks']      = 'Le ligamines a ressources de Windows functiona solmente in Microsoft Internet Explorer.
Tu pote nonobstante copiar e collar le ligamine.';
$lang['js']['linkwiz']         = 'Assistente pro ligamines';
$lang['js']['linkto']          = 'Ligar verso:';
$lang['js']['del_confirm']     = 'Realmente deler le entrata(s) seligite?';
$lang['mediausage']            = 'Usa le syntaxe sequente pro referer a iste file:';
$lang['mediaview']             = 'Vider file original';
$lang['mediaroot']             = 'radice';
$lang['mediaupload']           = 'Incarga hic un file in le spatio de nomines actual. Pro crear subspatios de nomines, antepone los al nomine de file "Incargar como", separate per signos de duo punctos (":").';
$lang['mediaextchange']        = 'Extension del file cambiate de .%s a .%s!';
$lang['reference']             = 'Referentias pro';
$lang['ref_inuse']             = 'Le file non pote esser delite proque illo es ancora in uso per le sequente paginas:';
$lang['ref_hidden']            = 'Alcun referentias es in paginas pro le quales tu non ha le permission de lectura';
$lang['hits']                  = 'Resultatos';
$lang['quickhits']             = 'Nomines de pagina correspondente';
$lang['toc']                   = 'Tabula de contento';
$lang['current']               = 'actual';
$lang['yours']                 = 'Tu version';
$lang['diff']                  = 'Monstrar differentias con versiones actual';
$lang['diff2']                 = 'Monstrar differentias inter le versiones seligite';
$lang['line']                  = 'Linea';
$lang['breadcrumb']            = 'Tracia';
$lang['youarehere']            = 'Tu es hic';
$lang['lastmod']               = 'Ultime modification';
$lang['by']                    = 'per';
$lang['deleted']               = 'removite';
$lang['created']               = 'create';
$lang['restored']              = 'ancian version restaurate (%s)';
$lang['external_edit']         = 'modification externe';
$lang['summary']               = 'Modificar summario';
$lang['noflash']               = 'Le <a href="http://www.adobe.com/products/flashplayer/">plug-in Flash de Adobe</a> es necessari pro monstrar iste contento.';
$lang['download']              = 'Discargar fragmento';
$lang['mail_newpage']          = 'pagina addite:';
$lang['mail_changed']          = 'pagina modificate:';
$lang['mail_subscribe_list']   = 'paginas modificate in spatio de nomines:';
$lang['mail_new_user']         = 'nove usator:';
$lang['mail_upload']           = 'file incargate:';
$lang['qb_bold']               = 'Texto grasse';
$lang['qb_italic']             = 'Texto italic';
$lang['qb_underl']             = 'Texto sublineate';
$lang['qb_code']               = 'Texto de codice';
$lang['qb_strike']             = 'Texto cancellate';
$lang['qb_h1']                 = 'Titulo a nivello 1';
$lang['qb_h2']                 = 'Titulo a nivello 2';
$lang['qb_h3']                 = 'Titulo a nivello 3';
$lang['qb_h4']                 = 'Titulo a nivello 4';
$lang['qb_h5']                 = 'Titulo a nivello 5';
$lang['qb_h']                  = 'Titulo';
$lang['qb_hs']                 = 'Seliger titulo';
$lang['qb_hplus']              = 'Titulo superior';
$lang['qb_hminus']             = 'Titulo inferior';
$lang['qb_hequal']             = 'Titulo al mesme nivello';
$lang['qb_link']               = 'Ligamine interne';
$lang['qb_extlink']            = 'Ligamine externe';
$lang['qb_hr']                 = 'Linea horizontal';
$lang['qb_ol']                 = 'Elemento de lista ordinate';
$lang['qb_ul']                 = 'Elemento de lista non ordinate';
$lang['qb_media']              = 'Adder imagines e altere files';
$lang['qb_sig']                = 'Inserer signatura';
$lang['qb_smileys']            = 'Emoticones     ';
$lang['qb_chars']              = 'Characteres special';
$lang['upperns']               = 'Saltar al spatio de nomines superior';
$lang['admin_register']        = 'Adder nove usator';
$lang['metaedit']              = 'Modificar metadatos';
$lang['metasaveerr']           = 'Scriptura de metadatos fallite';
$lang['metasaveok']            = 'Metadatos salveguardate';
$lang['img_backto']            = 'Retornar a';
$lang['img_title']             = 'Titulo';
$lang['img_caption']           = 'Legenda';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Nomine de file';
$lang['img_fsize']             = 'Dimension';
$lang['img_artist']            = 'Photographo';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formato';
$lang['img_camera']            = 'Camera';
$lang['img_keywords']          = 'Parolas-clave';
$lang['subscr_subscribe_success'] = '%s addite al lista de subscription de %s';
$lang['subscr_subscribe_error'] = 'Error durante le addition de %s al lista de subscription de %s';
$lang['subscr_subscribe_noaddress'] = 'Il non ha un adresse associate con tu conto. Tu non pote esser addite al lista de subscription.';
$lang['subscr_unsubscribe_success'] = '%s removite del lista de subscription de %s';
$lang['subscr_unsubscribe_error'] = 'Error durante le remotion de %s del lista de subscription de %s';
$lang['subscr_already_subscribed'] = '%s es ja subscribite a %s';
$lang['subscr_not_subscribed'] = '%s non es subscribite a %s';
$lang['subscr_m_not_subscribed'] = 'Tu non es actualmente subscribite al pagina o spatio de nomines actual.';
$lang['subscr_m_new_header']   = 'Adder subscription';
$lang['subscr_m_current_header'] = 'Subscriptiones actual';
$lang['subscr_m_unsubscribe']  = 'Cancellar subscription';
$lang['subscr_m_subscribe']    = 'Subscriber';
$lang['subscr_m_receive']      = 'Reciper';
$lang['subscr_style_every']    = 'un message pro cata modification';
$lang['authtempfail']          = 'Le authentication de usator temporarimente non es disponibile. Si iste situation persiste, per favor informa le administrator de tu wiki.';
$lang['i_chooselang']          = 'Selige tu lingua';
$lang['i_installer']           = 'Installator de DokuWiki';
$lang['i_wikiname']            = 'Nomine del wiki';
$lang['i_enableacl']           = 'Activar ACL (recommendate)';
$lang['i_superuser']           = 'Superusator';
$lang['i_problems']            = 'Le installator ha trovate alcun problemas, indicate hic infra. Tu debe resolver iste problemas pro poter continuar.';
$lang['i_modified']            = 'Pro motivos de securitate, iste script functiona solmente con un installation de DokuWiki nove e non modificate.
Tu debe re-extraher le files del pacchetto discargate, o consultar le <a href="http://dokuwiki.org/install">instructiones de installation</a> complete pro altere optiones.';
$lang['i_funcna']              = 'Le function PHP <code>%s</code> non es disponibile. Pote esser que tu albergo web lo ha disactivate pro un ration o altere.';
$lang['i_phpver']              = 'Le version de PHP <code>%s</code> es plus ancian que le version requisite <code>%s</code>. Es necessari actualisar le installation de PHP.';
$lang['i_permfail']            = '<code>%s</code> non permitte le accesso de scriptura a DokuWiki. Tu debe reparar le permissiones de iste directorio!';
$lang['i_confexists']          = '<code>%s</code> ja existe';
$lang['i_writeerr']            = 'Impossibile crear <code>%s</code>. Tu debe verificar le permissiones de directorios/files e crear iste file manualmente.';
$lang['i_badhash']             = 'dokuwiki.php non recognoscite o modificate (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valor vacue o invalide';
$lang['i_success']             = 'Le configuration ha succedite. Tu pote ora deler le file install.php. Continua a
<a href="doku.php?id=wiki:welcome">tu nove DokuWiki</a>.';
$lang['i_failure']             = 'Alcun errores occurreva durante le scriptura del files de configuration. Es possibile que tu debe remediar iste errores manualmente ante que
tu pote usar <a href="doku.php?id=wiki:welcome">tu nove DokuWiki</a>.';
$lang['i_policy']              = 'Politica de ACL interne';
$lang['i_pol0']                = 'Wiki aperte (lectura, scriptura, incargamento pro omnes)';
$lang['i_pol1']                = 'Wiki public (lectura pro omnes, scriptura e incargamento pro usatores registrate)';
$lang['i_pol2']                = 'Wiki claudite (lectura, scriptura e incargamento solmente pro usatores registrate)';
$lang['i_retry']               = 'Reprobar';
$lang['recent_global']         = 'Tu observa actualmente le modificationes intra le spatio de nomines <b>%s</b>. Tu pote etiam <a href="%s">vider le modificationes recente de tote le wiki</a>.';
$lang['years']                 = '%d annos retro';
$lang['months']                = '%d menses retro';
$lang['weeks']                 = '%d septimanas retro';
$lang['days']                  = '%d dies retro';
$lang['hours']                 = '%d horas retro';
$lang['minutes']               = '%d minutas retro';
$lang['seconds']               = '%d secundas retro';
